@@ -102,6 +102,7 @@ struct _GPMPPrivate {
 
 	/* Strict theme compliance [#96802] */
 	gboolean theme_compliance;
+	GtkWidget *use_theme_button;	
 };
 
 static void gpmp_parse_layout (GnomePrintJobPreview *mp);
@@ -511,8 +512,16 @@ canvas_style_changed_cb (GtkWidget *canvas, GtkStyle *ps, GnomePrintJobPreview *
 	priv = (GPMPPrivate *) mp->priv;
 
 	style = gtk_widget_get_style (GTK_WIDGET (canvas));
-	page_color = GPP_COLOR_RGBA (style->base [GTK_STATE_NORMAL], 0xff);
-	border_color = GPP_COLOR_RGBA (style->text [GTK_STATE_NORMAL], 0xff);
+	if (priv->theme_compliance) {
+		page_color = GPP_COLOR_RGBA (style->base [GTK_STATE_NORMAL], 
+					     0xff);
+		border_color = GPP_COLOR_RGBA (style->text [GTK_STATE_NORMAL], 
+					       0xff);
+	}
+	else {
+		page_color = GPP_COLOR_RGBA (style->white, 0xff);
+		border_color = GPP_COLOR_RGBA (style->black, 0xff);
+	}
 
 	for (i = 0; i < mp->page_array->len; i++) {
 		page = g_object_get_data (mp->page_array->pdata[i], "page");
@@ -521,6 +530,8 @@ canvas_style_changed_cb (GtkWidget *canvas, GtkStyle *ps, GnomePrintJobPreview *
 			       "outline_color_rgba", border_color,
 			       NULL);
 	}
+
+	gnome_print_job_preview_update (mp);
 }
 
 static void
@@ -572,13 +583,23 @@ entry_focus_out_event_cb (GtkWidget *widget, GdkEventFocus *event, GnomePrintJob
 	return FALSE;
 }
 
+static void
+check_button_toggled_cb (GtkWidget *widget, GnomePrintJobPreview *mp)
+{
+	GPMPPrivate *priv;
+	gboolean use_theme;
+	
+	priv = (GPMPPrivate *)mp->priv;
+	use_theme = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
+	priv->theme_compliance = use_theme;
+	gnome_print_preview_use_theme (use_theme);
+	g_signal_emit_by_name (G_OBJECT (priv->canvas), "style_set", NULL);
+}
+
 static void
 create_preview_canvas (GnomePrintJobPreview *mp)
 {
-	AtkRelationSet *relation_set;
-	AtkRelation *relation;
 	GPMPPrivate *priv;
-	AtkObject *relation_targets[1];
 	AtkObject *atko;
 	GtkWidget *status;
 	GtkWidget *l;
@@ -608,10 +629,8 @@ create_preview_canvas (GnomePrintJobPreview *mp)
 
 	gtk_container_add (GTK_CONTAINER (priv->scrolled_window), GTK_WIDGET (priv->canvas));
 
-	if (priv->theme_compliance) {
-		g_signal_connect (G_OBJECT (priv->canvas), "style_set",
-				  G_CALLBACK (canvas_style_changed_cb), mp);
-	}
+	g_signal_connect (G_OBJECT (priv->canvas), "style_set",
+			  G_CALLBACK (canvas_style_changed_cb), mp);
 	
 	status = gtk_hbox_new (FALSE, 0);
 	l = gtk_label_new_with_mnemonic (_("P_age: "));
@@ -639,19 +658,15 @@ create_preview_canvas (GnomePrintJobPreview *mp)
 	atk_object_set_name (atko, _("Page total"));
 	atk_object_set_description (atko, _("The total number of pages in the document"));
 
+	priv->use_theme_button = gtk_check_button_new_with_mnemonic (_("Use _theme colors for content"));
+	gtk_box_pack_end (GTK_BOX (status), priv->use_theme_button, FALSE,
+			    FALSE, 2);
+	g_signal_connect (G_OBJECT (priv->use_theme_button), "toggled",
+			  G_CALLBACK (check_button_toggled_cb), mp);
+
 	gtk_box_pack_start (GTK_BOX (mp->vbox), status, FALSE, FALSE, 3);
 	gtk_box_pack_start (GTK_BOX (mp->vbox), priv->scrolled_window, TRUE, TRUE, 0);
 
-	/* Add a LABELLED_BY relation from the page entry to the label. */
-	atko = gtk_widget_get_accessible (priv->page_entry);
-	relation_set = atk_object_ref_relation_set (atko);
-	relation_targets[0] = gtk_widget_get_accessible (l);
-	relation = atk_relation_new (relation_targets, 1,
-				     ATK_RELATION_LABELLED_BY);
-	atk_relation_set_add (relation_set, relation);
-	g_object_unref (G_OBJECT (relation));
-	g_object_unref (G_OBJECT (relation_set));
-
 	gtk_widget_show_all (mp->vbox);
 
 	gtk_widget_grab_focus (GTK_WIDGET (priv->canvas));
@@ -695,11 +710,13 @@ on_2x2_clicked (GtkMenuItem *i, GnomePrintJobPreview *mp)
 	preview_zoom_fit_cmd (NULL, mp);
 }
 
+#if 0
 static void
 on_other_clicked (GtkMenuItem *i, GnomePrintJobPreview *mp)
 {
 	g_warning ("Not implemented!");
 }
+#endif
 
 static void
 gpmp_multi_cmd (GtkWidget *w, GnomePrintJobPreview *mp)
@@ -731,11 +748,13 @@ gpmp_multi_cmd (GtkWidget *w, GnomePrintJobPreview *mp)
 	gtk_menu_attach (GTK_MENU (m), i, 1, 2, 1, 2);
         g_signal_connect (i, "activate", G_CALLBACK (on_2x2_clicked), mp);
 
+#if 0
         i = gtk_menu_item_new_with_label (_("Other"));
         gtk_widget_show (i);
 	gtk_menu_attach (GTK_MENU (m), i, 0, 2, 2, 3);
         gtk_widget_set_sensitive (i, FALSE);
         g_signal_connect (i, "activate", G_CALLBACK (on_other_clicked), mp);
+#endif
 
 	gtk_menu_popup (GTK_MENU (m), NULL, NULL, NULL, mp, 0,
 			GDK_CURRENT_TIME);
@@ -851,7 +870,7 @@ create_toplevel (GnomePrintJobPreview *mp)
 	gtk_widget_show (GTK_WIDGET (i));
 	gtk_toolbar_insert (GTK_TOOLBAR (tb), i, -1);
 
-	i = gtk_tool_button_new_from_stock (GTK_STOCK_MISSING_IMAGE);
+	i = gtk_tool_button_new_from_stock (GTK_STOCK_DND_MULTIPLE);
 	gtk_tool_item_set_tooltip (i, GTK_TOOLBAR (tb)->tooltips,
 				   _("View multiple pages"), "");
 	g_signal_connect (i, "clicked", G_CALLBACK (gpmp_multi_cmd), mp);
@@ -1217,9 +1236,13 @@ gnome_print_job_preview_new (GnomePrintJob *gpm, const guchar *title)
 	
 	if (priv->pagecount == 0) {
 		priv->pagecount = 1;
-		text = g_strdup (_("<markup>1   <span foreground=\"red\" "
-				   "weight=\"ultrabold\" background=\"white\">"
-				   "No visible output was created.</span></markup>"));
+		text = g_strdup_printf ("<markup>%d   "
+					"<span foreground=\"red\" "
+					"weight=\"ultrabold\" "
+					"background=\"white\">"
+					"%s</span></markup>",
+					1, 
+					_("No visible output was created."));
 	} else 
 		text =  g_strdup_printf ("%d", priv->pagecount);
 	gtk_label_set_markup_with_mnemonic (GTK_LABEL (priv->last), text);
